@@ -1,21 +1,21 @@
-import pytest
 from collections import defaultdict
+from copy import deepcopy
 from io import StringIO
 from pathlib import PosixPath
-from copy import deepcopy
 
+import pytest
 from docutils import nodes
-
-from numpydoc.numpydoc import (
-    mangle_docstrings,
-    _clean_text_signature,
-    update_config,
-    clean_backrefs,
-)
-from numpydoc.xref import DEFAULT_LINKS
 from sphinx.ext.autodoc import ALL
 from sphinx.util import logging
 
+from numpydoc.numpydoc import (
+    _clean_text_signature,
+    clean_backrefs,
+    mangle_docstrings,
+    update_config,
+)
+from numpydoc.xref import DEFAULT_LINKS
+
 
 class MockConfig:
     numpydoc_use_plots = False
@@ -49,6 +49,7 @@ class MockApp:
         self.verbosity = 2
         self._warncount = 0
         self.warningiserror = False
+        self._exception_on_warning = False
 
 
 def test_mangle_docstrings_basic():
@@ -101,7 +102,7 @@ A top section before
     mangle_docstrings(app, "class", "pathlib.PosixPath", PosixPath, {}, lines)
     lines = [x.strip() for x in lines]
     assert "samefile" in lines
-    app.config.numpydoc_show_inherited_class_members = defaultdict(lambda: False)
+    app.config.numpydoc_show_inherited_class_members = defaultdict(bool)
     lines = p.split("\n")
     mangle_docstrings(app, "class", "pathlib.PosixPath", PosixPath, {}, lines)
     lines = [x.strip() for x in lines]
@@ -142,7 +143,7 @@ def test_clean_text_signature():
     assert _clean_text_signature("func($self, *args)") == "func(*args)"
 
 
-@pytest.fixture
+@pytest.fixture()
 def f():
     def _function_without_seealso_and_examples():
         """
@@ -150,7 +151,6 @@ def f():
 
         Expect SA01 and EX01 errors if validation enabled.
         """
-        pass
 
     return _function_without_seealso_and_examples
 
